==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OsobaInformacjaDodatkowa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OsobaInformacjaDodatkowa extends GenericDPSObject {
    /**
     * OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaDodatkowaWpisId;

    /**
     * OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaDodatkowaWpisId() {
        return informacjaDodatkowaWpisId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     *
     * @param informacjaDodatkowaWpisId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaDodatkowaWpisId(Long informacjaDodatkowaWpisId) {
        this.informacjaDodatkowaWpisId = informacjaDodatkowaWpisId;
    }

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaInformacjaDodatkowa other = (OsobaInformacjaDodatkowa) that;
        return (this.getInformacjaDodatkowaWpisId() == null ? other.getInformacjaDodatkowaWpisId() == null : this.getInformacjaDodatkowaWpisId().equals(other.getInformacjaDodatkowaWpisId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInformacjaDodatkowaWpisId() == null) ? 0 : getInformacjaDodatkowaWpisId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", informacjaDodatkowaWpisId=").append(informacjaDodatkowaWpisId);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OsobaInformacjaDodatkowa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OsobaInformacjaDodatkowa extends GenericDPSObject {
    /**
     * OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaDodatkowaWpisId;

    /**
     * OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaDodatkowaWpisId() {
        return informacjaDodatkowaWpisId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.INFORMACJA_DODATKOWA_WPIS_ID
     *
     * @param informacjaDodatkowaWpisId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaDodatkowaWpisId(Long informacjaDodatkowaWpisId) {
        this.informacjaDodatkowaWpisId = informacjaDodatkowaWpisId;
    }

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_INFORMACJA_DODATKOWA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaInformacjaDodatkowa other = (OsobaInformacjaDodatkowa) that;
        return (this.getInformacjaDodatkowaWpisId() == null ? other.getInformacjaDodatkowaWpisId() == null : this.getInformacjaDodatkowaWpisId().equals(other.getInformacjaDodatkowaWpisId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInformacjaDodatkowaWpisId() == null) ? 0 : getInformacjaDodatkowaWpisId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", informacjaDodatkowaWpisId=").append(informacjaDodatkowaWpisId);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", osobaId=").append(osobaId);
        sb.append("]");
        return sb.toString();
    }
}
